Class: Aws::SupplyChain::Types::ListDataIntegrationFlowExecutionsRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-supplychain/types.rb

Overview

The request parameters of ListFlowExecutions.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#flow_nameString

The flow name.

Returns:

  • (String)


1814
1815
1816
1817
1818
1819
1820
1821
# File 'lib/aws-sdk-supplychain/types.rb', line 1814

class ListDataIntegrationFlowExecutionsRequest < Struct.new(
  :instance_id,
  :flow_name,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#instance_idString

The AWS Supply Chain instance identifier.

Returns:

  • (String)


1814
1815
1816
1817
1818
1819
1820
1821
# File 'lib/aws-sdk-supplychain/types.rb', line 1814

class ListDataIntegrationFlowExecutionsRequest < Struct.new(
  :instance_id,
  :flow_name,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The number to specify the max number of flow executions to fetch in this paginated request.

Returns:

  • (Integer)


1814
1815
1816
1817
1818
1819
1820
1821
# File 'lib/aws-sdk-supplychain/types.rb', line 1814

class ListDataIntegrationFlowExecutionsRequest < Struct.new(
  :instance_id,
  :flow_name,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The pagination token to fetch next page of flow executions.

Returns:

  • (String)


1814
1815
1816
1817
1818
1819
1820
1821
# File 'lib/aws-sdk-supplychain/types.rb', line 1814

class ListDataIntegrationFlowExecutionsRequest < Struct.new(
  :instance_id,
  :flow_name,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end