Class: Aws::SupplyChain::Types::ListDataIntegrationFlowExecutionsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::SupplyChain::Types::ListDataIntegrationFlowExecutionsResponse
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-supplychain/types.rb
Overview
The response parameters of ListFlowExecutions.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#flow_executions ⇒ Array<Types::DataIntegrationFlowExecution>
The list of flow executions.
-
#next_token ⇒ String
The pagination token to fetch next page of flow executions.
Instance Attribute Details
#flow_executions ⇒ Array<Types::DataIntegrationFlowExecution>
The list of flow executions.
1835 1836 1837 1838 1839 1840 |
# File 'lib/aws-sdk-supplychain/types.rb', line 1835 class ListDataIntegrationFlowExecutionsResponse < Struct.new( :flow_executions, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The pagination token to fetch next page of flow executions.
1835 1836 1837 1838 1839 1840 |
# File 'lib/aws-sdk-supplychain/types.rb', line 1835 class ListDataIntegrationFlowExecutionsResponse < Struct.new( :flow_executions, :next_token) SENSITIVE = [] include Aws::Structure end |