Class: Aws::SupplyChain::Types::ListDataIntegrationFlowExecutionsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SupplyChain::Types::ListDataIntegrationFlowExecutionsRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-supplychain/types.rb
Overview
The request parameters of ListFlowExecutions.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#flow_name ⇒ String
The flow name.
-
#instance_id ⇒ String
The AWS Supply Chain instance identifier.
-
#max_results ⇒ Integer
The number to specify the max number of flow executions to fetch in this paginated request.
-
#next_token ⇒ String
The pagination token to fetch next page of flow executions.
Instance Attribute Details
#flow_name ⇒ String
The flow name.
1814 1815 1816 1817 1818 1819 1820 1821 |
# File 'lib/aws-sdk-supplychain/types.rb', line 1814 class ListDataIntegrationFlowExecutionsRequest < Struct.new( :instance_id, :flow_name, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The AWS Supply Chain instance identifier.
1814 1815 1816 1817 1818 1819 1820 1821 |
# File 'lib/aws-sdk-supplychain/types.rb', line 1814 class ListDataIntegrationFlowExecutionsRequest < Struct.new( :instance_id, :flow_name, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The number to specify the max number of flow executions to fetch in this paginated request.
1814 1815 1816 1817 1818 1819 1820 1821 |
# File 'lib/aws-sdk-supplychain/types.rb', line 1814 class ListDataIntegrationFlowExecutionsRequest < Struct.new( :instance_id, :flow_name, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The pagination token to fetch next page of flow executions.
1814 1815 1816 1817 1818 1819 1820 1821 |
# File 'lib/aws-sdk-supplychain/types.rb', line 1814 class ListDataIntegrationFlowExecutionsRequest < Struct.new( :instance_id, :flow_name, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |